==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/SeedCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.mystias_izakaya.MystiasIzakaya;
import cc.thonly.mystias_izakaya.block.MIBlocks;
import cc.thonly.reverie_dreams.block.CropBlockCreator;
import cc.thonly.reverie_dreams.block.WoodCreator;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Map;

public class SeedCreativeTab implements ItemGroupContentHelper {

    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, MystiasIzakaya.id("seeds_item_group"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(SeedCreativeTab::getSeedItemIcon)
            .method_47321(class_2561.method_43471("item_group.seed_item_group"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(SeedCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            for (Map.Entry<class_2960, CropBlockCreator.Instance> view : CropBlockCreator.getViews()) {
                CropBlockCreator.Instance instance = view.getValue();
                class_1792 seed = instance.getSeed();
                itemGroup.method_45421(seed);
            }
            itemGroup.method_45421(MIBlocks.UDUMBARA_FLOWER);
            itemGroup.method_45421(MIBlocks.TREMELLA);
            WoodCreator.INSTANCES.forEach((instance) -> itemGroup.method_45421(instance.sapling()));

        });
        ItemGroupContentHelper.registerGroup(SeedCreativeTab.ITEM_GROUP_KEY, SeedCreativeTab.ITEM_GROUP);

    }

    public static class_1799 getSeedItemIcon() {
        for (Map.Entry<class_2960, CropBlockCreator.Instance> view : CropBlockCreator.getViews()) {
            CropBlockCreator.Instance instance = view.getValue();
            return new class_1799(instance.getSeed());
        }
        return new class_1799(class_1802.field_8317);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/SeedCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.block.creator.CropBlockCreator;
import cc.thonly.reverie_dreams.block.creator.WoodCreator;
import cc.thonly.reverie_dreams.registry.content.block.RDWoodBlocks;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Map;

public class SeedCreativeTab implements ItemGroupContentHelper {

    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, ReverieDreams.id("seeds_item_group"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(SeedCreativeTab::getSeedItemIcon)
            .method_47321(class_2561.method_43471("item_group.seed_item_group"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(SeedCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            for (Map.Entry<class_2960, CropBlockCreator.Instance> view : CropBlockCreator.getViews()) {
                CropBlockCreator.Instance instance = view.getValue();
                class_1792 seed = instance.getSeed();
                itemGroup.method_45421(seed);
            }
            itemGroup.method_45421(RDWoodBlocks.UDUMBARA_FLOWER);
            itemGroup.method_45421(RDWoodBlocks.TREMELLA);
            WoodCreator.INSTANCES.forEach((instance) -> itemGroup.method_45421(instance.sapling()));

        });
        ItemGroupContentHelper.registerGroup(SeedCreativeTab.ITEM_GROUP_KEY, SeedCreativeTab.ITEM_GROUP);

    }

    public static class_1799 getSeedItemIcon() {
        for (Map.Entry<class_2960, CropBlockCreator.Instance> view : CropBlockCreator.getViews()) {
            CropBlockCreator.Instance instance = view.getValue();
            return new class_1799(instance.getSeed());
        }
        return new class_1799(class_1802.field_8317);
    }
}
